A python package that provides Neural Networks to estimate ages of stars.

Based on an upcoming paper by Boin et al. 2025.

# Dependencies:
- numpy
- scikit (optional but recommended for speed)
- tqdm (optional)
- matplotlib (optional)

The [documentation website](https://star-age.github.io/NEST-docs/) guides you through the package usage.

A [Web interface](https://star-age.github.io/) of the project is available to quickly test the Neural Networks:

![image](https://star-age.github.io/NEST-docs/_images/website.png)